@@ -112,7 +112,7 @@ def revert_allocation_for_migration(context, source_cn, instance, migration):
 class MigrationTask(base.TaskBase):
     def __init__(self, context, instance, flavor,
                  request_spec, clean_shutdown, compute_rpcapi,
-                 query_client, report_client, host_list):
+                 query_client, report_client, host_list, network_api):
         super(MigrationTask, self).__init__(context, instance)
         self.clean_shutdown = clean_shutdown
         self.request_spec = request_spec
@@ -122,6 +122,7 @@ class MigrationTask(base.TaskBase):
         self.query_client = query_client
         self.reportclient = report_client
         self.host_list = host_list
+        self.network_api = network_api
 
         # Persist things from the happy path so we don't have to look
         # them up if we need to roll back
@@ -184,6 +185,106 @@ class MigrationTask(base.TaskBase):
             self.request_spec.requested_destination = objects.Destination(
                 cell=instance_mapping.cell_mapping)
 
+    def _support_resource_request(self, selection):
+        """Returns true if the host is new enough to support resource request
+        during migration and that the RPC API version is not pinned during
+        rolling upgrade.
+        """
+        svc = objects.Service.get_by_host_and_binary(
+            self.context, selection.service_host, 'nova-compute')
+        return (svc.version >= 39 and
+                self.compute_rpcapi.supports_resize_with_qos_port(
+                    self.context))
+
+    # TODO(gibi): Remove this compat code when nova doesn't need to support
+    # Train computes any more.
+    def _get_host_supporting_request(self, selection_list):
+        """Return the first compute selection from the selection_list where
+        the service is new enough to support resource request during migration
+        and the resources claimed successfully.
+
+        :param selection_list: a list of Selection objects returned by the
+            scheduler
+        :return: A two tuple. The first item is a Selection object
+            representing the host that supports the request. The second item
+            is a list of Selection objects representing the remaining alternate
+            hosts.
+        :raises MaxRetriesExceeded: if none of the hosts in the selection_list
+            is new enough to support the request or we cannot claim resource
+            on any of the hosts that are new enough.
+        """
+
+        if not self.request_spec.requested_resources:
+            return selection_list[0], selection_list[1:]
+
+        # Scheduler allocated resources on the first host. So check if the
+        # first host is new enough
+        if self._support_resource_request(selection_list[0]):
+            return selection_list[0], selection_list[1:]
+
+        # First host is old, so we need to use an alternate. Therefore we have
+        # to remove the allocation from the first host.
+        self.reportclient.delete_allocation_for_instance(
+            self.context, self.instance.uuid)
+        LOG.debug(
+            'Scheduler returned host %(host)s as a possible migration target '
+            'but that host is not new enough to support the migration with '
+            'resource request %(request)s or the compute RPC is pinned to '
+            'less than 5.2. Trying alternate hosts.',
+            {'host': selection_list[0].service_host,
+             'request': self.request_spec.requested_resources},
+            instance=self.instance)
+
+        alternates = selection_list[1:]
+
+        for i, selection in enumerate(alternates):
+            if self._support_resource_request(selection):
+                # this host is new enough so we need to try to claim resources
+                # on it
+                if selection.allocation_request:
+                    alloc_req = jsonutils.loads(
+                        selection.allocation_request)
+                    resource_claimed = scheduler_utils.claim_resources(
+                        self.context, self.reportclient, self.request_spec,
+                        self.instance.uuid, alloc_req,
+                        selection.allocation_request_version)
+
+                    if not resource_claimed:
+                        LOG.debug(
+                            'Scheduler returned alternate host %(host)s as a '
+                            'possible migration target but resource claim '
+                            'failed on that host. Trying another alternate.',
+                            {'host': selection.service_host},
+                            instance=self.instance)
+                    else:
+                        return selection, alternates[i + 1:]
+
+                else:
+                    # Some deployments use different schedulers that do not
+                    # use Placement, so they will not have an
+                    # allocation_request to claim with. For those cases,
+                    # there is no concept of claiming, so just assume that
+                    # the resources are available.
+                    return selection, alternates[i + 1:]
+
+            else:
+                LOG.debug(
+                    'Scheduler returned alternate host %(host)s as a possible '
+                    'migration target but that host is not new enough to '
+                    'support the migration with resource request %(request)s '
+                    'or the compute RPC is pinned to less than 5.2. '
+                    'Trying another alternate.',
+                    {'host': selection.service_host,
+                     'request': self.request_spec.requested_resources},
+                    instance=self.instance)
+
+        # if we reach this point then none of the hosts was new enough for the
+        # request or we failed to claim resources on every alternate
+        reason = ("Exhausted all hosts available during compute service level "
+                  "check for instance %(instance_uuid)s." %
+                  {"instance_uuid": self.instance.uuid})
+        raise exception.MaxRetriesExceeded(reason=reason)
+
     def _execute(self):
         # TODO(sbauza): Remove once all the scheduler.utils methods accept a
         # RequestSpec object in the signature.
@@ -202,8 +303,12 @@ class MigrationTask(base.TaskBase):
         # is not forced to be the original host
         self.request_spec.reset_forced_destinations()
 
-        # TODO(gibi): We need to make sure that the requested_resources field
-        # is re calculated based on neutron ports.
+        port_res_req = self.network_api.get_requested_resource_for_instance(
+            self.context, self.instance.uuid)
+        # NOTE(gibi): When cyborg or other module wants to handle similar
+        # non-nova resources then here we have to collect all the external
+        # resource requests in a single list and add them to the RequestSpec.
+        self.request_spec.requested_resources = port_res_req
 
         self._restrict_request_spec_to_cell(legacy_props)
 
@@ -232,51 +337,12 @@ class MigrationTask(base.TaskBase):
         # pop the first alternate from the list to use for the destination, and
         # pass the remaining alternates to the compute.
         if self.host_list is None:
-            selection_lists = self.query_client.select_destinations(
-                    self.context, self.request_spec, [self.instance.uuid],
-                    return_objects=True, return_alternates=True)
-            # Since there is only ever one instance to migrate per call, we
-            # just need the first returned element.
-            selection_list = selection_lists[0]
-            # The selected host is the first item in the list, with the
-            # alternates being the remainder of the list.
-            selection, self.host_list = selection_list[0], selection_list[1:]
+            selection = self._schedule()
+
         else:
             # This is a reschedule that will use the supplied alternate hosts
-            # in the host_list as destinations. Since the resources on these
-            # alternates may have been consumed and might not be able to
-            # support the migrated instance, we need to first claim the
-            # resources to verify the host still has sufficient availabile
-            # resources.
-            elevated = self.context.elevated()
-            host_available = False
-            while self.host_list and not host_available:
-                selection = self.host_list.pop(0)
-                if selection.allocation_request:
-                    alloc_req = jsonutils.loads(selection.allocation_request)
-                else:
-                    alloc_req = None
-                if alloc_req:
-                    # If this call succeeds, the resources on the destination
-                    # host will be claimed by the instance.
-                    host_available = scheduler_utils.claim_resources(
-                            elevated, self.reportclient, self.request_spec,
-                            self.instance.uuid, alloc_req,
-                            selection.allocation_request_version)
-                else:
-                    # Some deployments use different schedulers that do not
-                    # use Placement, so they will not have an
-                    # allocation_request to claim with. For those cases,
-                    # there is no concept of claiming, so just assume that
-                    # the host is valid.
-                    host_available = True
-            # There are no more available hosts. Raise a MaxRetriesExceeded
-            # exception in that case.
-            if not host_available:
-                reason = ("Exhausted all hosts available for retrying build "
-                          "failures for instance %(instance_uuid)s." %
-                          {"instance_uuid": self.instance.uuid})
-                raise exception.MaxRetriesExceeded(reason=reason)
+            # in the host_list as destinations.
+            selection = self._reschedule()
 
         scheduler_utils.populate_filter_properties(legacy_props, selection)
         # context is not serializable
@@ -304,6 +370,73 @@ class MigrationTask(base.TaskBase):
             node=node, clean_shutdown=self.clean_shutdown,
             host_list=self.host_list)
 
+    def _schedule(self):
+        selection_lists = self.query_client.select_destinations(
+            self.context, self.request_spec, [self.instance.uuid],
+            return_objects=True, return_alternates=True)
+        # Since there is only ever one instance to migrate per call, we
+        # just need the first returned element.
+        selection_list = selection_lists[0]
+
+        selection, self.host_list = self._get_host_supporting_request(
+            selection_list)
+
+        scheduler_utils.fill_provider_mapping(
+            self.context, self.reportclient, self.request_spec, selection)
+        return selection
+
+    def _reschedule(self):
+        # Since the resources on these alternates may have been consumed and
+        # might not be able to support the migrated instance, we need to first
+        # claim the resources to verify the host still has sufficient
+        # available resources.
+        elevated = self.context.elevated()
+        host_available = False
+        selection = None
+        while self.host_list and not host_available:
+            selection = self.host_list.pop(0)
+            if (self.request_spec.requested_resources and not
+                    self._support_resource_request(selection)):
+                LOG.debug(
+                    'Scheduler returned alternate host %(host)s as a possible '
+                    'migration target for re-schedule but that host is not '
+                    'new enough to support the migration with resource '
+                    'request %(request)s. Trying another alternate.',
+                    {'host': selection.service_host,
+                     'request': self.request_spec.requested_resources},
+                    instance=self.instance)
+                continue
+            if selection.allocation_request:
+                alloc_req = jsonutils.loads(selection.allocation_request)
+            else:
+                alloc_req = None
+            if alloc_req:
+                # If this call succeeds, the resources on the destination
+                # host will be claimed by the instance.
+                host_available = scheduler_utils.claim_resources(
+                    elevated, self.reportclient, self.request_spec,
+                    self.instance.uuid, alloc_req,
+                    selection.allocation_request_version)
+                if host_available:
+                    scheduler_utils.fill_provider_mapping(
+                        self.context, self.reportclient, self.request_spec,
+                        selection)
+            else:
+                # Some deployments use different schedulers that do not
+                # use Placement, so they will not have an
+                # allocation_request to claim with. For those cases,
+                # there is no concept of claiming, so just assume that
+                # the host is valid.
+                host_available = True
+        # There are no more available hosts. Raise a MaxRetriesExceeded
+        # exception in that case.
+        if not host_available:
+            reason = ("Exhausted all hosts available for retrying build "
+                      "failures for instance %(instance_uuid)s." %
+                      {"instance_uuid": self.instance.uuid})
+            raise exception.MaxRetriesExceeded(reason=reason)
+        return selection
+
     def rollback(self):
         if self._migration:
             self._migration.status = 'error'
