@@ -734,8 +734,9 @@ class Instance(base.NovaPersistentObject, base.NovaObject,
         pass
 
     def _save_keypairs(self, context):
-        # NOTE(danms): Read-only so no need to save this.
-        pass
+        if 'keypairs' in self.obj_what_changed():
+            self._save_extra_generic('keypairs')
+            self.obj_reset_changes(['keypairs'], recursive=True)
 
     def _save_extra_generic(self, field):
         if field in self.obj_what_changed():
