@@ -15,7 +15,7 @@
 from oslo_utils import uuidutils
 from oslo_utils import versionutils
 
-from nova import db
+from nova.db import api as db
 from nova.db.sqlalchemy import api as db_api
 from nova.db.sqlalchemy import models
 from nova import objects
