@@ -31,7 +31,7 @@ LOG = logging.getLogger(__name__)
 
 
 # NOTE(danms): This is the global service version counter
-SERVICE_VERSION = 37
+SERVICE_VERSION = 40
 
 
 # NOTE(danms): This is our SERVICE_VERSION history. The idea is that any
@@ -151,6 +151,16 @@ SERVICE_VERSION_HISTORY = (
     {'compute_rpc': '5.0'},
     # Version 37: prep_resize takes a RequestSpec object
     {'compute_rpc': '5.1'},
+    # Version 38: set_host_enabled reflects COMPUTE_STATUS_DISABLED trait
+    {'compute_rpc': '5.1'},
+    # Version 39: resize_instance, finish_resize, revert_resize,
+    # finish_revert_resize, unshelve_instance takes a RequestSpec object
+    {'compute_rpc': '5.2'},
+    # Version 40: Add migration and limits parameters to
+    # check_can_live_migrate_destination(), new
+    # drop_move_claim_at_destination() method, and numa_live_migration
+    # parameter to check_can_live_migrate_source()
+    {'compute_rpc': '5.3'},
 )
 
 
