@@ -75,6 +75,7 @@ def fake_db_instance(**updates):
                   'vcpu_model': None,
                   'device_metadata': None,
                   'trusted_certs': None,
+                  'resources': None,
                  },
         'tags': [],
         'services': []
@@ -118,7 +119,6 @@ def fake_instance_obj(context, obj_instance_class=None, **updates):
                                 is_public=True,
                                 extra_specs={},
                                 projects=[])
-        flavor.obj_reset_changes()
     inst = obj_instance_class._from_db_object(context,
                obj_instance_class(), fake_db_instance(**updates),
                expected_attrs=expected_attrs)
@@ -132,12 +132,14 @@ def fake_instance_obj(context, obj_instance_class=None, **updates):
             inst.vcpus = flavor.vcpus
         if 'memory_mb' in flavor and 'memory_mb' not in updates:
             inst.memory_mb = flavor.memory_mb
-        if ('instance_type_id' not in inst or inst.instance_type_id is None
-                and 'id' in flavor):
+        if ('instance_type_id' not in inst or
+                inst.instance_type_id is None and
+                'id' in flavor):
             inst.instance_type_id = flavor.id
     inst.old_flavor = None
     inst.new_flavor = None
-    inst.obj_reset_changes()
+    inst.resources = None
+    inst.obj_reset_changes(recursive=True)
     return inst
 
 
