@@ -30,9 +30,12 @@ class Dom0IptablesFirewallDriver(firewall.IptablesFirewallDriver):
     def _plugin_execute(self, *cmd, **kwargs):
         # Prepare arguments for plugin call
         args = {}
+        process_input = kwargs.get('process_input', None)
+        if process_input is not None and isinstance(process_input, bytes):
+            kwargs['process_input'] = process_input.decode('utf-8')
         args.update(map(lambda x: (x, str(kwargs[x])), kwargs))
         args['cmd_args'] = jsonutils.dumps(cmd)
-        ret = self._session.call_plugin('xenhost', 'iptables_config', args)
+        ret = self._session.call_plugin('xenhost.py', 'iptables_config', args)
         json_ret = jsonutils.loads(ret)
         return (json_ret['out'], json_ret['err'])
 
@@ -41,7 +44,8 @@ class Dom0IptablesFirewallDriver(firewall.IptablesFirewallDriver):
         super(Dom0IptablesFirewallDriver, self).__init__(**kwargs)
         self._session = xenapi_session
         # Create IpTablesManager with executor through plugin
-        self.iptables = linux_net.IptablesManager(self._plugin_execute)
+        self.iptables = linux_net.IptablesManager(
+            redirect_privsep_calls_to=self._plugin_execute)
         self.iptables.ipv4['filter'].add_chain('sg-fallback')
         self.iptables.ipv4['filter'].add_rule('sg-fallback', '-j DROP')
         self.iptables.ipv6['filter'].add_chain('sg-fallback')
